@@ -9,7 +9,7 @@ function(para) {
               L3   = NULL,
               L4   = NULL,
               L5   = NULL,
-              source = "lmomgam--ordinary"
+              source = "lmomgam"
              )
     # Note that TAU5 and L5 are not available from Hosking's FORTRAN base.
 
