@@ -1,14 +1,14 @@
 "pp" <-
-function(x,A=0,B=1) {
-    if(A <= -1 | A >= B) {
-      warning("Plotting position parameters are invalid")
+function(x,a=0) {
+    if(a < 0) {
+      warning("Plotting position parameter is invalid")
       return()
     }
     N <- length(x)
     pp <- vector(mode = "numeric")
 
     for(i in seq(1,N)) {
-      pp[i] <- (i+A)/(N+B)
+      pp[i] <- (i-a)/(N+1-2*a)
     }
     return(pp)
 }
